@@ -32,6 +32,7 @@
 #include <gnome.h>
 
 #include <regex.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h> 
 #include <bonobo-activation/bonobo-activation.h>
@@ -45,6 +46,10 @@
 #define BINARY_EXEC_MIME_TYPE      "application/x-executable-binary"
 #define ICON_THEME_EXECUTABLE_ICON "gnome-fs-executable"
 #define ICON_THEME_REGULAR_ICON    "gnome-fs-regular"
+#define ICON_THEME_CHAR_DEVICE     "gnome-fs-chardev"
+#define ICON_THEME_BLOCK_DEVICE    "gnome-fs-blockdev"
+#define ICON_THEME_SOCKET          "gnome-fs-socket"
+#define ICON_THEME_FIFO            "gnome-fs-fifo"
 
 
 /* START OF THE GCONF FUNCTIONS */
@@ -185,6 +190,24 @@ is_path_in_mount_folder (const gchar *path)
 	return (g_strstr_len (path, strlen ("/mnt/"), "/mnt/") != NULL);
 }
 
+gboolean 
+is_path_in_proc_folder (const gchar *path)
+{
+	return (g_strstr_len (path, strlen ("/proc/"), "/proc/") != NULL);
+}
+
+gboolean 
+is_path_in_dev_folder (const gchar *path)
+{
+	return (g_strstr_len (path, strlen ("/dev/"), "/dev/") != NULL);
+}
+
+gboolean 
+is_path_in_var_folder (const gchar *path)
+{
+	return (g_strstr_len (path, strlen ("/var/"), "/var/") != NULL);
+}
+
 gboolean 
 is_path_in_tmp_folder (const gchar *path)
 {
@@ -436,44 +459,48 @@ strdup_strftime (const gchar *format,
 	return result;
 }
 
-gchar *
-get_file_type_with_mime_type (const gchar *filename, 
-			      const gchar *mimetype)
+const char *
+get_file_type_for_mime_type (const gchar *filename, 
+                             const gchar *mimetype)
 {
+	const char *desc;
+	
 	if (filename == NULL || mimetype == NULL) {
-		return (gchar *)gnome_vfs_mime_get_description (GNOME_VFS_MIME_TYPE_UNKNOWN);
+		return gnome_vfs_mime_get_description (GNOME_VFS_MIME_TYPE_UNKNOWN);
 	}
 
+	desc = gnome_vfs_mime_get_description (mimetype);
+
 	if (g_file_test (filename, G_FILE_TEST_IS_SYMLINK)) {
-		if (g_ascii_strcasecmp (mimetype, GNOME_VFS_MIME_TYPE_UNKNOWN) == 0) {
-			GnomeVFSFileInfo *file_info;
+	
+		GnomeVFSFileInfo *file_info;
 		
-			file_info = gnome_vfs_file_info_new ();
-			gnome_vfs_get_file_info (filename, file_info, GNOME_VFS_FILE_INFO_DEFAULT);
+		file_info = gnome_vfs_file_info_new ();
+		gnome_vfs_get_file_info (filename, file_info, GNOME_VFS_FILE_INFO_DEFAULT);
 		
-			if (g_file_test (file_info->symlink_name, G_FILE_TEST_EXISTS) != TRUE) {
+		if (g_file_test (file_info->symlink_name, G_FILE_TEST_EXISTS) != TRUE) {
+		
+			if ((g_ascii_strcasecmp (mimetype, "x-special/socket") != 0) && 
+		            (g_ascii_strcasecmp (mimetype, "x-special/fifo") != 0)) {
+			    
 				gnome_vfs_file_info_unref (file_info);
 				return _("link (broken)");
 			}
-			
-			gnome_vfs_file_info_unref (file_info);
 		}
-		return g_strdup_printf (_("link to %s"), 
-			(gchar *)gnome_vfs_mime_get_description (mimetype));
+			
+		gnome_vfs_file_info_unref (file_info);
+		return g_strdup_printf (_("link to %s"), (desc != NULL) ? desc : mimetype);
 	}
-
-	return (gchar *)gnome_vfs_mime_get_description (mimetype);
+	return desc;
 } 
 
-gchar *
-get_file_icon_with_mime_type (const gchar *filename, 
-			      const gchar *mimetype) 
+GdkPixbuf *
+get_file_pixbuf_for_mime_type (const gchar *filename, 
+			       const gchar *mimetype) 
 {
-	const GnomeIconData *icon_data;
-	gchar *icon_name = NULL;	
-	gchar *icon_path = NULL;
-	int base_size;
-
+	GdkPixbuf *pixbuf;
+	gchar *icon_name = NULL;
+	
 	if (filename == NULL || mimetype == NULL) {
 		icon_name = g_strdup (ICON_THEME_REGULAR_ICON);
 	}
@@ -481,15 +508,33 @@ get_file_icon_with_mime_type (const gchar *filename,
 	         (g_ascii_strcasecmp (mimetype, "application/x-executable-binary") == 0)) {
 		icon_name = g_strdup (ICON_THEME_EXECUTABLE_ICON);
 	}
+	else if (g_ascii_strcasecmp (mimetype, "x-special/device-char") == 0) {
+		icon_name = g_strdup (ICON_THEME_CHAR_DEVICE);
+	}
+	else if (g_ascii_strcasecmp (mimetype, "x-special/device-block") == 0) {
+		icon_name = g_strdup (ICON_THEME_BLOCK_DEVICE);
+	}
+	else if (g_ascii_strcasecmp (mimetype, "x-special/socket") == 0) {
+		icon_name = g_strdup (ICON_THEME_SOCKET);
+	}
+	else if (g_ascii_strcasecmp (mimetype, "x-special/fifo") == 0) {
+		icon_name = g_strdup (ICON_THEME_FIFO);
+	}
 	else {
-		icon_name = gnome_icon_lookup (interface.icon_theme, NULL, filename, NULL, 
+		icon_name = gnome_icon_lookup (gtk_icon_theme_get_default (), NULL, filename, NULL, 
 					       NULL, mimetype, 0, NULL);
 	}
-
-	icon_path = gnome_icon_theme_lookup_icon (interface.icon_theme, icon_name, ICON_SIZE, 
-						  &icon_data, &base_size);
+	
+	pixbuf = (GdkPixbuf *) g_hash_table_lookup (search_command.pixbuf_hash, icon_name);
+	
+	if (pixbuf == NULL) {
+		pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), icon_name, 
+		                                   ICON_SIZE, 0, NULL);
+		g_hash_table_insert (search_command.pixbuf_hash, g_strdup (icon_name), pixbuf);
+	}
+						  
 	g_free (icon_name);
-	return icon_path;	
+	return pixbuf;
 }
 
 gboolean
@@ -514,11 +559,9 @@ is_nautilus_running (void)
 gboolean
 is_component_action_type (const gchar *filename)
 {
-	gchar *mimeType = gnome_vfs_get_mime_type (filename);	
+	const char *mimeType = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);	
 	GnomeVFSMimeActionType actionType = gnome_vfs_mime_get_default_action_type (mimeType);
 	
-	g_free (mimeType);
-	
 	if (actionType == GNOME_VFS_MIME_ACTION_TYPE_COMPONENT) {
 		return TRUE;
 	}
@@ -546,10 +589,8 @@ open_file_with_nautilus (const gchar *filename)
 gboolean
 open_file_with_application (const gchar *filename)
 {
-	gchar *mimeType = gnome_vfs_get_mime_type (filename);	
+	const char *mimeType = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);	
 	GnomeVFSMimeApplication *mimeApp = gnome_vfs_mime_get_default_application (mimeType);
-	
-	g_free (mimeType);
 		
 	if (mimeApp) {
 		gint  argc;
@@ -577,7 +618,7 @@ open_file_with_application (const gchar *filename)
 gboolean
 launch_file (const gchar *filename)
 {
-	gchar *mime_type = gnome_vfs_get_mime_type (filename);	
+	const char *mime_type = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);	
 	gboolean result = FALSE;
 	
 	if ((g_file_test (filename, G_FILE_TEST_IS_EXECUTABLE)) &&
@@ -585,7 +626,6 @@ launch_file (const gchar *filename)
 		result = g_spawn_command_line_async (filename, NULL);
 	}
 	
-	g_free (mime_type);
 	return result;
 }
 
@@ -632,123 +672,28 @@ gsearchtool_unique_filename (const gchar *dir,
 	return retval;
 }
 
-GtkWidget*
-gsearchtool_hig_dialog_new (GtkWindow      *parent,
-                            GtkDialogFlags flags,
-                            GtkButtonsType buttons,
-                            const gchar    *header,
-                            const gchar    *message)
+GtkWidget *
+gsearchtool_button_new_with_stock_icon (const gchar *label, 
+                                        const gchar *stock_id)
 {
-	GtkWidget *dialog;
-	GtkWidget *dialog_vbox;
-	GtkWidget *dialog_action_area;
-	GtkWidget *hbox;
-	GtkWidget *vbox;
-	GtkWidget *label;
+	GtkWidget *align;
 	GtkWidget *button;
+	GtkWidget *hbox;
 	GtkWidget *image;
-	gchar     *title;
-
-	dialog = gtk_dialog_new ();
+	GtkWidget *l;
 	
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-  
-	dialog_vbox = GTK_DIALOG (dialog)->vbox;
-	gtk_box_set_spacing (GTK_BOX (dialog_vbox), 14);
-
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_widget_show (hbox);
-
-	if (buttons != GTK_BUTTONS_OK_CANCEL && buttons != GTK_BUTTONS_YES_NO) {
-		image = gtk_image_new_from_stock ("gtk-dialog-error", GTK_ICON_SIZE_DIALOG);
-	}
-	else {
-		image = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_DIALOG);
-	}
+	/* Copied from eel-gtk-extensions. */
+	button = gtk_button_new ();
+	l = gtk_label_new_with_mnemonic (label);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (l), GTK_WIDGET (button));
+	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+	hbox = gtk_hbox_new (FALSE, 2);
+	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_widget_show (image);
+	gtk_box_pack_end (GTK_BOX (hbox), l, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (button), align);
+	gtk_container_add (GTK_CONTAINER (align), hbox);
+	gtk_widget_show_all (align);
 
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-	gtk_widget_show (vbox);
-	
-	title = g_strconcat ("<b>", header, "</b>", NULL);
-	label = gtk_label_new (title);  
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	g_free (title);
-	
-	label = gtk_label_new (message);
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	
-	dialog_action_area = GTK_DIALOG (dialog)->action_area;
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
-
-	switch (buttons) 
-  	{		
-		case GTK_BUTTONS_OK_CANCEL:
-	
-			button = gtk_button_new_from_stock ("gtk-cancel");
-  			gtk_widget_show (button);
-  			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_CANCEL);
-  			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
-		  	button = gtk_button_new_from_stock ("gtk-ok");
-  			gtk_widget_show (button);
-  			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
-  			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-			break;
-		
-		/* The HIG advises against using YES/NO dialogs.  We don't use them; instead, this
-		   dialog type is being used for a CANCEL/DELETE dialog. */  		
-		case GTK_BUTTONS_YES_NO:
-	
-			button = gtk_button_new_from_stock ("gtk-cancel");
-  			gtk_widget_show (button);
-  			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_CANCEL);
-  			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
-		  	button = gtk_button_new_from_stock ("gtk-delete");
-  			gtk_widget_show (button);
-  			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
-  			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-			break;
-			
-		case GTK_BUTTONS_OK:
-		
-			button = gtk_button_new_from_stock ("gtk-ok");
-			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
-			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-			gtk_widget_show (button);
-			break;
-		
-		default:
-			g_warning ("Unhandled GtkButtonsType");
-			break;
-  	}
-
-	if (parent != NULL) {
-		gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
-	}
-	if (flags & GTK_DIALOG_MODAL) {
-		gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	}
-	if (flags & GTK_DIALOG_DESTROY_WITH_PARENT) {
-		gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-	}
-	
-  	return dialog;
+	return button;
 }
