@@ -33,7 +33,7 @@ extern "C" {
 #pragma }
 #endif
 
-#define ICON_SIZE 24.0
+#define ICON_SIZE 24
 
 gboolean  	
 is_path_hidden 			(const gchar *path);
@@ -44,6 +44,15 @@ is_path_in_home_folder 		(const gchar *path);
 gboolean  	
 is_path_in_mount_folder		(const gchar *path);
 
+gboolean  	
+is_path_in_proc_folder		(const gchar *path);
+
+gboolean  	
+is_path_in_dev_folder		(const gchar *path);
+
+gboolean  	
+is_path_in_var_folder		(const gchar *path);
+
 gboolean  	
 is_path_in_tmp_folder		(const gchar *path);
 
@@ -71,11 +80,11 @@ get_readable_date 		(const time_t file_time_raw);
 gchar *    	
 strdup_strftime 		(const gchar *format, 
 				 struct tm *time_pieces); 
-gchar *
-get_file_type_with_mime_type	(const gchar *filename,
+const char *
+get_file_type_for_mime_type	(const gchar *filename,
 				 const gchar *mimetype);
-gchar *
-get_file_icon_with_mime_type 	(const gchar *filename,
+GdkPixbuf *
+get_file_pixbuf_for_mime_type 	(const gchar *filename,
 				 const gchar *mimetype);
 gboolean  	
 is_nautilus_running 		(void);
