@@ -28,15 +28,9 @@
 #ifndef _GSEARCHTOOL_H_
 #define _GSEARCHTOOL_H_
 
-#define GDK_DISABLE_DEPRECATED
-#define GDK_PIXBUF_DISABLE_DEPRECATED
-#define G_DISABLE_DEPRECATED
-#define GTK_DISABLE_DEPRECATED
-#define GNOME_DISABLE_DEPRECATED
-
 #define MINIMUM_WINDOW_WIDTH   422
 #define MINIMUM_WINDOW_HEIGHT  310
-#define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool.png"
+#define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool"
 
 #ifdef __cplusplus
 extern "C" {
@@ -81,7 +75,6 @@ typedef enum {
 struct _SearchStruct {
 	gint			pid;
 	gint 	        	timeout;
-	gint			animation_timeout;
 	gchar			*look_in_folder;
 	gchar           	*file_is_named_pattern;
 	gchar 	  		*regex_string;
@@ -89,7 +82,9 @@ struct _SearchStruct {
 	gboolean		show_hidden_files;
 	gboolean		regex_matching_enabled;
 	gboolean		not_running_timeout;
+	gboolean		aborted;
 	RunStatus        	running;
+	GHashTable              *pixbuf_hash;
 } search_command;
 
 struct _InterfaceStruct {
@@ -99,11 +94,11 @@ struct _InterfaceStruct {
 	GtkWidget		*stop_button;
 	GtkWidget 		*save_button;
 	GtkWidget 		*main_window;	
-	GtkWidget		*drawing_area;
+	GtkWidget               *spinner;
 	GdkPixbuf		*pixbuf;	
 	GtkWidget		*table;	
 	GtkWidget 		*file_selector;
-	GtkWidget		*checkbutton;
+	GtkWidget		*expander;
 	GtkWidget		*add_button;
 	GtkWidget 		*additional_constraints;
 	GtkWidget		*constraint_menu;
@@ -119,8 +114,6 @@ struct _InterfaceStruct {
 	GList 			*selected_constraints;
 	gchar 		 	*save_results_file;	
 	gint 		  	selected_constraint;
-	gint			current_animation_frame;
-	GnomeIconTheme	 	*icon_theme;
 	gboolean  	  	is_gail_loaded;
 } interface;
 
@@ -157,12 +150,6 @@ set_constraint_selected_state	(gint		constraint_id,
 void
 set_constraint_gconf_boolean 	(gint 		constraint_id, 
 				 gboolean 	flag);
-gboolean
-update_progress_bar 		(gpointer data);
-
-gboolean
-update_animation_timeout_cb 	(gpointer data);
-
 void
 set_clone_command		(gint *argcp,
 				 gchar ***argvp,
@@ -171,6 +158,9 @@ set_clone_command		(gint *argcp,
 gchar *
 get_desktop_item_name 		(void);
 
+void
+update_search_counts 		(void);
+
 #ifdef __cplusplus
 }
 #endif
