@@ -54,7 +54,7 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
 	  return;
   }
 
-  logo = gdk_pixbuf_new_from_file (DATADIR G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "gnome-log.png", NULL);
+  logo = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "logviewer", 48, 0, NULL);
   about_window = gnome_about_new (_("System Log Viewer"), VERSION,
            			  "Copyright \xc2\xa9 1998-2003 Free Software Foundation, Inc.",
 				  _(comments),
